# frozen_string_literal: true

require 'dalli'
require 'connection_pool'
require 'mcache/version'
require 'mcache/client'
require 'mcache/config'
require 'mcache/connection'

module Mcache
  def self.configure(&block)
    @config = Mcache::Config.new
    @config.instance_eval &block if block_given?

    @connection = Mcache::Connection.new(
      @config.host,
      @config.pool_size,
      @config.timeout,
      @config.options
    )
  end

  def self.fetch(key, options = {})
    Mcache::Client.new.fetch(key, options) do
      yield
    end
  end

  private_class_method

  def self.connection
    configure unless @connection
    @connection
  end
end
